---
slug: "streamer-audio-2021-05-04"
title: "The Streamer's Guide to Audio"
date: "2021-08-02"
modified: "2021-08-02"
description: "A simple guide to amazing audio for your Twitch streams without breaking the bank. Written by an audio professional for live streamers"
---
*Don't panic.*

Audio is by far one of the most important, yet misunderstood parts of livestreaming. If you have great video quality but horrible sound people aren't going to stick around. On the other hand, if you sound great, but your video isn't the best, there's going to be a significantly higher chance to keep people around.

Given that fact, it's interesting to see that a lot of streamers (and youtubers) don't seem to really understand sound, which tends to result in it becoming a weak point of their whole production. A lot of people just buy the most expensive thing they can afford and expect it to be a magic bullet, which usually isn't the case. Other people just buy what other big streamers are using, often getting pulled into the same bad decisions as their idols. This usually leads to streamers spending a lot more money than they need to in order to end up with remotely decent audio. This guide will allow you to spend less money and get better audio than most of Twitch. This will allow you to spend more money on other parts of your streaming setup!

In this article I want to give you more insight in the world of broadcast audio. There will be some solid recommendations for hardware that works well for streaming, and advice on getting the most out of your hardware.

I want to begin with some **free** ways to make (almost) any microphone sound a lot better, using something that we in the professional audio world call:

## Processing

Processing means taking a raw input signal from a mic, and applying certain effects and techniques to it to make it sound good. Any sound engineer will tell you that a cheap microphone with well-executed processing is better than a very high end microphone with no processing at all. No matter how good your microphone is, it will sound terrible at worst and mediocre at best if you feed it straight into Twitch. Doing processing right can be the difference between terrible audio and good audio, or the difference between good audio and great audio. That makes it absolutely worthwile to take the time to get a basic understanding of and get right.

Processing can look quite scary if you don't know what it all means, so let me give you a quick overview of some of the most used processing techniques in the audio industry. I'll go over what they each do, and how you can apply them in OBS for the low low price of free!

To make it easier to hear what you're doing when changing the processing settings in OBS, you can enable "monitoring". What monitoring does is take the final OBS audio signal and play it back through your headphones so you can hear what it sounds like. To enable monitoring, click the gear icon next to any input in the `Audio Mixer` section in OBS, and select `Advanced Audio Properties`. In the window that pops up, set the `Audio Monitoring` option to `Monitor and Output` and restart OBS. You should now hear yourself in your headphones when you talk into your microphone. If you still can't hear yourself you can try going into the main OBS settings' Audio tab, and make sure to select your headphones as the monitoring device. Do keep in mind that monitoring in OBS will have pretty terrible delay to it, so I would recommend turning it off after you're done tweaking your settings.

### Gain

The first step in the journey from a raw signal to a good-sounding output is the input gain. Gain is the sensitivity of your input. The higher the gain, the more use you're making of the full range of your interface, but too high gain will result in a distorted signal. The goal is to get your gain to be as high as possible, without the signal ever maxing out and clipping. When possible, you want to set your gain on your audio interface. If you don't have hardware gain control, you can set the gain in OBS.

To add gain control in OBS you have to click the gear icon next to your microphone input in the `Audio Mixer` section of OBS and choose "Filters" from the menu. Then hit the `+` icon in the bottom left and choose Gain. 

It's also a good idea to set the `Peak Meter Type` to `True Peak` mode. While this uses a very tiny amount more CPU, it will give you a far more accurate readout on the audio meters. You can find this setting in the `Audio` tab of the main settings window in OBS.

To properly set the gain, make sure you can see the audio meter in OBS. Then set the actual input volumein the `Audio Mixer` panel to full. Now yell as loudly as you can into your microphone, and adjust the gain setting on your interface or the `Gain` slider in OBS until the signal goes just slightly above the -5 mark. Make very sure that the signal never touches the 0 mark. If the whole meter goes red it means your input is clipping, which means you need to turn your gain down.

With your raw signal level sorted out we can move on to the proper processing of the signal.

### Equalization

Equalization (or EQ, for short) is the process of raising and lowering the volum of certain frequencies in an audio signal. On a very basic level that means you can, for example, add more bass to a signal, or tone down some annoying high frequencies.

The specific settings differ per microphone, but one thing you'll always want to add for voice recording is a *low-cut* (or a *high-pass*, same thing). What a low-cut does is entirely removes the sound below a certain frequency. The reason you want to do that is that microphones have a tendency to pick sounds that are close to them up with a lot more bass than your ears would at normal speaking distance. This can result in a very annoying, boomy voice sound on your stream. You usually want to to set your low-cut to around 80hZ, but feel free to play around with it to get to a place where you like the sound.

Besides low-cut, you can also use equalization to tweak the microphone sound. For example, if it sounds a bit muddy to your liking, you can remove some bass, and if you want some more clarity to the sound, you can boost the higher frequency a bit. Sounding a bit thin? add some mid-range.

One thing to keep in mind with EQ is that subtlety is key. having too much or too little of any frequency is going to sound bad, so while it can be tempting, the trick is to not overdo it.

#### Using an EQ in OBS

Sadly, OBS doesn't include an equalizer. But it does support something called VST. VST are plugins you can use for processing, effects and virtual synths in most professional audio editing programs. For this tutorial, I'll be using ReaPlugs, which is a set of free VST plugins provided by Reaper. You can download ReaPlugs [here](https://www.reaper.fm/reaplugs/). It's important to get the proper version (32-bit or 64-bit) for you OBS install. Make sure to download ReaPlugs via the links on the page. Don't click the "DOWNLOAD REAPER" at the top of the page, that's for a Reaper, a fully-featured audio editing software which we won't be needing.

  After installing ReaPlugs and restarting OBS, go to the `Audio Mixer` section and click the gear icon for the Mic/Aux input. In the menu that pops up, select `Filters`. You'll now see the audio filters window for your microphone input in OBS. To add the ReaPlugs equalizer, click the `+` button in the bottom left, select `VST 2.x Plug-in`, and give it a name. Then click `{Please select a plugin}` and select `reaeq-standalone` in the dropdown menu and click the `Open Plug-in Interface` button. 
  
{% figure "/img/blog/streamaudio/eq.png" "A screenshot of the ReqEQ UI" "The ReaEQ UI"%}

You should now be presented with the ReaEQ plugin controls. If you speak into your mic you should see some things start to move in the visualizer section at the top. The moving squiggly line is a representation of the frequencies coming in and their volumes. The more to the right on the graph, the higher the frequency. 

Below the visualizer, you see the settings for each "band" of the equalizer. Each band represents one modification to the incoming signal. For the first band, you'll want to set the type to "High Pass", and the frequency to 80.

To tweak your sound more, you can drag the numbered dots on the visualizer directly. dragging left to right changes the frequency, and dragging up and down changes how much louder or quieter to make that frequency. to change the width of an adjustment, you can change the "bandwidth" setting. 

Don't just copy the settings in the screenshot above! Equalization settings are unique for each person, and for each microphone.

### Compression and Dynamic Range

Dynamic range in audio means how much difference there is between the loudest and quietest the signal gets. Classical music, for example, has a lot of dynamic range, where more modern music tends to have very low dynamic range. The human voice has quite a lot of dynamic range, especially when moving around a mic. This is actually not a great thing for speech, especially over background sounds. There's a way to reduce that dynamic range though, and it's called (dynamic) compression. Dynamic compressions should not be confused with data compression, which is taking an audio file and compressing it's data for smaller file sizes, often losing overall quality in the process.

A compressor takes highest peaks of the signal and make them quieter. Then it takes the whole signal and boosts the volume. The upside of this is that if you talk into the microphone very loudly nobody will have their eardrums blown out, and if you talk into the microphone quietly people can still hear what you're saying. Decreased dynamic range also helps your voice stand out above background noise, like game sounds and background music, without needing the background sound to be very quiet, or your voice to be very loud.

There are a couple of key settings that are in every compressor:

**Threshold:**
The volume level where the compression kicks in. Any signal below the threshold will not be the compressed at all.

**Attack:**
This is how quickly the compressor responds. setting it too slow will result in a loud peak on sudden loud input, but setting it too fast will sound weird.

**Release:**
How long it takes to bring the volume back up when the input signal goes down. If this is set too slow your signal will sound quiet, but if it's set too fast it can sound quite weird. 

**Ratio:**
This is how much the dynamic range gets compressed. If it's set to 4:1, you need 4dB over the threshold to have the output rise by 1dB. Lowering the ratio will leave you more dynamic range for a more natural sound with bigger volume differences, while raising it will limit the signal more, and reduce the dynamic range which allows you to get more "loudness" with a higher make-up gain.

**Make-up gain:**
Make-up gain, or output level, is how much to boost the end result by. A compressor, by default, only makes things quieter, and you'll probably want to pull that signal back up to get it to a proper level.

One thing that's important to keep in mind with compression is that adding too much of it (higher ratio, lower threshold) will also bring out hiss and background noise more.

You can really see the differences between a compressed and an uncompressed signal if you look at the waveform for each. Notice how the signal in the compressed sound is a lot more consistent than the uncompressed signal.

{%figure "/img/blog/streamaudio/comp-wav.png" "An image comparing the difference between a compresed and an uncompressed audio signal" "The same audio signal, without and with compression" %}

#### Using compression in OBS

Although OBS has a built-in compressor, we'll be using the one included with ReaPlugs as it's a bit nicer to use. To add the compressor plugin, add another VST 2.x Plug-in to your mic audio filters. Click `{Please select a plug-in}` and select `reacomp-standalone`, then click `Open Plug-in Interface`, you should now be presented with the ReaComp options screen.

{%figure "/img/blog/streamaudio/comp.png" "A screenshot of the ReaComp UI" "The ReaComp UI" %}

To set your compressor up properly, you first need to talk into your microphone at your normal speaking level. When you start talking, you should see the big meter on the left of the plugin start to move. Set the slider between the big meters to a bit above where the signal is peaking. Then set the `ratio` setting to 5, the `attack` to 10ms and the `release` to 100ms. Then enable `Auto make-up` and `Limit output` and you should have a good starting point. At this point it's a good idea to record some test footage with talking both quietly and loudly, and listening to it to hear how it will sound on-stream.

Now that your microphone processing is all done, it's time to move on to the next part of getting your audio right:

## Mixing

It's important to mix your different audio sources properly. You want your viewers to easily hear and understand your voice, but you also don't want your other sounds, like music and game sounds to be too quiet.

First of all, you want to get the mic volume right. Your voice is the most important sound on the stream, so it should always take priority over other things. When speaking at your normal speaking volume you ideally want it to just slightly hit the red zone. If you go as loud as you ever would on stream, it should never ever touch the top of the meter. If it does, you should lower the volume or play with the threshold and ratio on the compressor.

Any other background sounds in your mix, like game sound and background music should just slightly touch the yellow zone of the meter in OBS when at their loudest.

A good way to test if your mixing is right is to get everything set up as if you were going to stream. This includes getting a game of choice started up and having your background music going. After getting ready, just hit `Start Recording` instead of `Start Streaming`, but act as if you're live. Pretend to stream for about 10 minutes, and listen back to the video. You'll now know exactly how your sound is going to be on stream. If there are things that sound out of wack, just adjust your settings, and repeat the process until everything is just perfect.

## Microphones

Now that you know about ways to make your microphone sound good, it's time to talk about hardware. If you've applied processing, but you're still not happy with your microphone quality, or don't have a microphone to begin with it might be time for an upgrade. But don't think you need to go and spend hundreds of dollars on a microphone to get good sound on your streams or video, as you can get better sound than the majority of streamers on twitch with a microphone under 100 dollars and apply the processing described above.

One thing I'd also like to add that it's a good idea to buy a pop filter for any of the mics on this list (except the C520 and ATGM2), there are many out there, and it's best to search for yourself, as there isn't a lot of difference between most of them. A pop filter will help with plosives (P and B noises, for example), and will help against the sound of breathing into your mic.

But before I make any specific recommendations for microphones I want to talk about the two main types of microphones there are.

### Condenser Microphones

If you've spent any time streaming, you've probably heard of the Blue Yeti. The Yeti is a condenser microphone. I won't bore you of the details about how they work, but the general gist of them is that they're *very* sensitive. That might sound like a good thing, but in reality this is actually a downside for streaming.

Condenser microphones are a great option in a studio environment, whith a proper sound-proofed room without *any* ambient noise in the room. The reality is that, for speech, the extra sensitivity that a condenser mic brings to the table won't add much to the quality. On the other hand, it will pick up every single little bit of background noise like your keyboard, PC fans, mouse clicks and putting your drink down on your desk.

That considered, I really can't recommend buying a condenser microphone for streaming, unless you're a professional sound engineer who knows how to deal with one properly. But if you are, why are you even reading this article?

There is another, more suitable option though:

### Dynamic Microphones

Dynamic microphones are a lot less sensitive than condenser microphones. That means that you generally need to get them very close to your face to talk into them, usually no more than 25cm or so away. That might be a bit of a hassle, but easy to solve with a proper mic stand. The massive upside to using a dynamic microphone is that they are very resistive to picking up background noise. 

I use a dynamic mic (Shure SM58) for my daily voice chats with people. While it picks up my voice just fine it doesn't pick up my mechanical keyboard at all, and I can even have the call on my speakers at a comfortable volume without the people in the call hearing themselves. And all of that is without even applying any noise reduction to the signal.

While I will say that tools like RTX voice are very good at removing background noise, it'll always be better not to have any background noise in your signal to begin with. Noise reduction will always have a negative effect on the total sound quality.

### Pickup patterns
Different microphones can have different pickup patterns. A pickup pattern basically is how sensitive a microphone is to sounds coming in from different directions. There are several general pickup patterns that you'll see in microphones.

- **Omnidirectional**: Omni is latin for all, which makes the name quite self-explanatory. Omni microphones will pick up sound from every angle with more or less the same volume. A lot of gaming headset microphones are omnidirectional, which is one of the reasons a lot of them are quite bad at rejecting outside noise.
- **Cardioid** will mostly only pick up sound coming from the front. the more off-axis the sound, the less loud it will be.
- **Super/Hypercardioid** are like cardioid, but will pick up some degree of sound from the opposite side too.
- **Figure of eight** will pick up sound from the front and the back equally, but will be less sensive from the sides.

For streaming, you'll usually want some form of cardioid mic, as there's usually nothing behind the mic you'll want to pick up.

## So which mic should I get then?

Before diving into recommendations, I want to take a quick moment to go over a couple of things that probably **aren't** worth investing in for livestreaming:

- **Shure SM7B:** While being a very nice, high end studio microphone, it's completely and utterly overkill for livestreaming voice recording and there really is nothing to gain for you here, except showing off the fact that you have more money than you know what to do with. I'll be listing some significantly cheaper options that will sound just as good, if not better than a SM7B in the actual recommendations.
- **Blue Yeti:** Being a condenser studio microphone, it will pick up a huge amount of background noise. Additionally, it's actually quite over-priced for the quality you get for it. The built in USB interface of it is also not particularly great.
- **Gaming Headsets:** The microphones built into gaming headsets are generally added as an afterthought, and are usually not of the quality you'd expect looking at the amount of money you pay for them. It's generally a better idea to buy a separate headset mic you can attach to a pair of headphones you already own. I'll have a couple of options for those later on.

With those hot takes out of the way, I'll get on with the things I *do* recommend buying. While I'm ordering these by price, that doesn't mean you should buy the most expensive one you can afford. I'm including microphones of various form factors in here, that are suited better for different people based on use case and personal preference. With that said, here are my picks. All of the microphones on this list have an XLR connector and will require an USB-XLR interface unless otherwise specified. My picks for interfaces will be further down this page. 

<span class="text-xs">The prices listed here are from Thomann and Sweetwater at the time of writing. If the product couldn't be found on Thomann/Sweetwater I've gone for the lowest non-discounted price from a reputable retailer. None of these products or websites are sponsoring me in any way, please feel free to buy anywhere you prefer.</span>

### Behringer XM8500 Ultravoice: €15.90/$19.00
[Thomann](https://www.thomann.de/intl/behringer_xm8500.htm)
| [Sweetwater](https://www.sweetwater.com/store/detail/XM8500--behringer-xm8500-handheld-dynamic-vocal-microphone)

This is by far the cheapest microphone I can reasonably recommend, but it's already infinitely better than pretty much any webcam, laptop, phone or headset microphone. This is a dynamic mic, so a low distance from your face is important when using the XM5800.

If you can live with it being right up in your face this is an outstanding microphone, especially for the money, but overall too. It's more than enough to make your stream sound decent with some proper processing.

### Audio-Technica ATGM2: €80/$79
[Amazon US](https://www.amazon.com/Audio-Technica-ATGM2-Detachable-Boom-Microphone/dp/B07JV798YV)

If you really want a headset microphone, you might want to give the ATGM2 a look. Instead of being a full headset, you can attach this mic to any headphones you already own! It's similar to the AntLion modmic, but sounds way better in my opinion. It has a 3.5mm jack connection. This means you can use it on your PC soundcard if you're in a real pinch. I do recommend getting yourself a dedicated interface and a Rode VXLR+ to get the most out of it.

It is a bit more sensitive than the dynamic options, so you might get a little bit of keyboard noise through it if your keyboard is loud enough, but because it's quite close to your mouth it'll still be significantly better than a regular condenser microphone.

It can be a bit hard to find, but it's available on amazon and local retailers in a bunch of countries. Your best bet will be to do a quick Google search.

### Shure SM58: €98/$99
[Thomann](https://www.thomann.de/intl/shure_sm58.htm?ref=search_rslt_SM58_105767_0_1_98f0d30c-aec9-4497-9eee-e1647924bc13)
| [Sweetwater](https://www.sweetwater.com/store/detail/SM58--shure-sm58-cardioid-dynamic-vocal-microphone)

The Shure SM58 is the industry standard microphone for live music vocals all over the world. Your favourite artist has probably sung into this microphones, and if it's good enough for them it's definitely good enough for twitch. 

The passive noise cancelling on this microphone is by far the best on this list. The SM58 is made to be used on concert stages. It is designed to minimize feedback, even with very loud concert speakers blasting at it.

The capsule (the bit of the microphone that captures the physical soundwaves and turns them into electricity) of the SM58 is also quite similar to the one in the SM7B. It takes a lot less gain to drive though, so you won't need a separate pre-amplifier to get good sound out of it.

Like the XM8500 this is a dynamic microphone, so the same care should be taken with positioning it close to your face.

Upsides compared to the XM8500 are that it has a built in pop filter, built in shock dampening, better build quality and a better frequency range. It's also [pretty much indestructible](https://www.youtube.com/watch?v=95U7wxPQZdE)

### Rode PodMic: €105/$99
[Thomann](https://www.thomann.de/intl/rode_podmic.htm)
| [Sweetwater](https://www.sweetwater.com/store/detail/PodMic--rode-podmic-dynamic-broadcast-microphone)

If you want something that sounds a bit nicer than the SM58, and don't mind a bit of a bulkier microphone, you might want to give the PodMic a look. It's by far the best sounding mic on this list if you get the processing on it right, and well worth the price. It takes a bit more gain to get the right volume than the SM58, but should be well within the capabilities of the two interfaces I'm recommending later on in this post.

### Elgato Wave 3: €160/$147
[Amazon NL](https://www.amazon.nl/dp/B088HHWC47/ref=asc_df_B088HHWC471620473280000/?tag=tweakersnl-21&creative=380333&creativeASIN=B088HHWC47&linkCode=asn)
| [Amazon US](https://www.amazon.com/Elgato-Wave-Microphone-Podcasting-Capacitive/dp/B088HHWC47/ref=sr_1_2?dchild=1&keywords=wave%3A3&qid=1620514820&sr=8-2)

The Elgato Wave:3 is the only USB microphone I will recommend at this point. It's also my top pick for streamers on the market right now. They have all of the processing built into their own software, and is very user-friendly to set up. It's the second most expensive mic on this list, but you won't need to deal with interfaces or doing the processing yourself. If you can afford it, and are looking for a desk mic: this is the one.

The Wave:1 is also quite good, and definitely gets a solid recommendation too, but including it separately on this feels a bit excessive.

### AKG C520: €215/$219
[Sweetwater](https://www.sweetwater.com/store/detail/C520--akg-c-520-headworn-microphone)

The second headset microphone on this list, but with a twist. Instead of mounting it on a pair of headphones, you wear it directly on your head. This option sounds quite a bit better than the ATGM2, and is a bit bulkier too. It might also be slightly uncomfortable under some headphones due to the ear hooks it uses. I have seen [MrGregles](https://twitch.tv/mrgregles) mount this mic to his headphones using black gaffer tape, which has been extremely effective so far. 

This mic does need something called phantom power, so make sure to turn that on on your interface if you're trying to use it. Both interfaces I'm recommending in this post have phantom power built in. 

Do not confuse this mic with the cheaper AKG C 520L, which was made to work with AKG's wireless mic system, and can't easily be connected to a normal interface. 

The C520 is a great options for streamers who want something that sounds better than the ATGM2, but don't want a microphone on a stand in front of them.

<br />

Now that we have a microphone it's time to move on to the second part of the hardware setup:

## Interfaces

The interface is a box that takes an analogue sound signal from your microphone and turns it into a digital signal your PC can use. Once you're above a certain level of interface, you're going to be more than fine for pretty much anything, save very high end recording. Please don't spend too much money on an interface, as the options outlined here are already more than you'll ever need.

There are very high end audio interfaces, that offer things like extremely high end specs, high resolution audio, extremely high bitrates. The fact of the matter is that Twitch won't take any more than 48kHz 16bit audio, compressed down to no more than 320kbit/s. Both of the interfaces I'm recommending here will do more than amazingly for streaming.

One interface you might expect here is the Focusrite Scarlett 2i2. The reason I've left it out is that I know a *lot* of people who have had issues with their focusrite products, and haven't had the greatest experience with their support to get those issues solved. 

I'm also leaving out the GoXLR line of products, as the quality of them is very substandard. The sound quality of the interface in them is absolute garbage compared to anything listed below, and the build quality isn't great either. All that considered they're significantly more expensive than they have any right to be, and are mostly a less than mediocre audio interface with a huge "gamer tax" slapped onto it. If there's **one thing** you should take away from all of these hardware recommendations, it's that the GoXLR is not worth it, *ever*.

### Behringer U-Phoria UMC202HD: €64/$79
[Thomann](https://www.thomann.de/intl/behringer_u_phoria_umc202hd.htm)
| [Sweetwater](https://www.sweetwater.com/store/detail/UMC202HD--behringer-u-phoria-umc202hd-usb-audio-interface)

The UMC202HD is a very capable little interface, not only for the price but also in general. It supports 2 microphone inputs, supports 192kHz, 24bit audio input which is not only enough for twitch, but even for some basic instrument recording or voiceover work. The Midas Designed pre-amps in this are significantly better than those in the GoXLR, and are similar to, if not better quality than on the X32 line of professional sound mixers.

### Audient EVO 4: € 119
[Thomann](https://www.thomann.de/intl/audient_evo_4.htm)
| [Sweetwater](https://www.sweetwater.com/store/detail/EVO4--audient-evo-4-usb-audio-interface)

If you're a musician you might want to look at the EVO 4 by Audient. Besides 24-bit 96kHz, it also features a dedicated JFET instrument input. It's a chunk more pricy than the Behringer, and if you don't need the instrument input, you're probably better off going for the UMC202HD and spending the extra money on other investments in your setup.

## In conclusion
I hope this article has helped shed some light onto getting the audio for your streams right. Good audio is one of the keystones to a successful stream, and this knowledge should give you a definite edge in the field. 

Besides that, there are a couple of people I'd like to thank for their help with this article:
- [droppedtree88](https://twitter.com/droppedtree88): A professional studio engineer, for extra insights, second opinions and calling me out on any bullshit.
- [MrGregles](https://twitter.com/Mrgregles): A full time professional Twitch streamer, for insights from a streamer's perspective.
